library robomotion_app_lib;

import 'package:flutter/widgets.dart';
import 'package:dio/dio.dart';

Dio _dio = Dio();

class Robomotion {
  final Config config;
  final Widget app;
  String _apiURL;

  Robomotion({@required this.config, @required this.app}) {
    _apiURL = _getAPIUrl();
  }

  void run() {
    _register().then((_) => runApp(this.app));
  }

  Future<void> _register() async {
    String url = "${this._apiURL}/v1/apps.register";
    Response<Map> resp = await _dio.post(url,
        options: Options(headers: {
          'Authorization': this.config.token,
          'Content-Type': 'application/json; charset=UTF-8',
        }),
        data: {
          'repository_id': this.config.repositoryID,
          'namespace': this.config.namespace,
          'url': this.config.url,
        });

    if (!resp.data.containsKey("ok") || !resp.data["ok"]) {
      throw new Exception("Application registration failed: ${resp.data.toString()}");
    }
  }

  String _getAPIUrl() {
    String ws = this.config.workspace;
    List<String> parts = ws.split(".");
    String domain = parts.getRange(1, parts.length).join(".");
    String protocol = parts[0].split("//")[0];
    return domain == "robomotion.io" ? "$protocol//api.$domain" : "$ws/api";
  }
}

class Config {
  final String namespace;
  final String token;
  final String repositoryID;
  final String url;
  final String workspace;

  Config(
      {@required this.namespace,
      @required this.token,
      @required this.repositoryID,
      @required this.url,
      @required this.workspace});
}
